@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '1.94';
+$CPAN::Perl::Releases::VERSION = '1.98';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -154,6 +154,8 @@ our $data =
 "5.18.3-RC2" => { id => 'RJBS' },
 "5.18.3" => { id => 'RJBS' },
 "5.18.4" => { id => 'RJBS' },
+"5.21.5" => { id => 'ABIGAIL' },
+"5.21.6" => { id => 'BINGOS' },
 };
 
 sub perl_tarballs {
@@ -210,7 +212,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 1.94
+version 1.98
 
 =head1 SYNOPSIS
 
